type token =
  | CODE of (Coqpp_ast.code)
  | COMMENT of (string)
  | IDENT of (string)
  | QUALID of (string)
  | STRING of (string)
  | INT of (int)
  | VERNAC
  | TACTIC
  | GRAMMAR
  | DOC_GRAMMAR
  | EXTEND
  | END
  | DECLARE
  | PLUGIN
  | DEPRECATED
  | ARGUMENT
  | RAW_PRINTED
  | GLOB_PRINTED
  | SYNTERP
  | COMMAND
  | CLASSIFIED
  | STATE
  | PRINTED
  | TYPED
  | INTERPRETED
  | GLOBALIZED
  | SUBSTITUTED
  | BY
  | AS
  | BANGBRACKET
  | HASHBRACKET
  | LBRACKET
  | RBRACKET
  | PIPE
  | ARROW
  | FUN
  | COMMA
  | EQUAL
  | STAR
  | LPAREN
  | RPAREN
  | COLON
  | SEMICOLON
  | GLOBAL
  | TOP
  | FIRST
  | LAST
  | BEFORE
  | AFTER
  | LEVEL
  | LEFTA
  | RIGHTA
  | NONA
  | EOF

open Parsing;;
let _ = parse_error;;
# 12 "coqpp/coqpp_parse.mly"

open Coqpp_ast

let starts s pat =
  let len = String.length s in
  let patlen = String.length pat in
  if patlen <= len && String.sub s 0 patlen = pat then
    Some (String.sub s patlen (len - patlen))
  else None

let ends s pat =
  let len = String.length s in
  let patlen = String.length pat in
  if patlen <= len && String.sub s (len - patlen) patlen = pat then
    Some (String.sub s 0 (len - patlen))
  else None

let between s pat1 pat2 = match starts s pat1 with
| None -> None
| Some s -> ends s pat2  

let without_sep k sep r =
  if sep <> "" then raise Parsing.Parse_error else k r

let parse_user_entry s sep =
  let table = [
    "ne_", "_list", without_sep (fun r -> Ulist1 r);
    "ne_", "_list_sep", (fun sep r -> Ulist1sep (r, sep));
    "", "_list", without_sep (fun r -> Ulist0 r);
    "", "_list_sep", (fun sep r -> Ulist0sep (r, sep));
    "", "_opt", without_sep (fun r -> Uopt r);
  ] in
  let rec parse s sep = function
  | [] ->
    let () = without_sep ignore sep () in
    begin match starts s "tactic" with
    | Some ("0"|"1"|"2"|"3"|"4"|"5" as s) -> Uentryl ("tactic", int_of_string s)
    | Some _ | None -> Uentry s
    end
  | (pat1, pat2, k) :: rem ->
    match between s pat1 pat2 with
    | None -> parse s sep rem
    | Some s ->
      let r = parse s "" table in
      k sep r      
  in
  parse s sep table

let no_code = { code = ""; loc = None }

# 111 "coqpp/coqpp_parse.ml"
let yytransl_const = [|
  263 (* VERNAC *);
  264 (* TACTIC *);
  265 (* GRAMMAR *);
  266 (* DOC_GRAMMAR *);
  267 (* EXTEND *);
  268 (* END *);
  269 (* DECLARE *);
  270 (* PLUGIN *);
  271 (* DEPRECATED *);
  272 (* ARGUMENT *);
  273 (* RAW_PRINTED *);
  274 (* GLOB_PRINTED *);
  275 (* SYNTERP *);
  276 (* COMMAND *);
  277 (* CLASSIFIED *);
  278 (* STATE *);
  279 (* PRINTED *);
  280 (* TYPED *);
  281 (* INTERPRETED *);
  282 (* GLOBALIZED *);
  283 (* SUBSTITUTED *);
  284 (* BY *);
  285 (* AS *);
  286 (* BANGBRACKET *);
  287 (* HASHBRACKET *);
  288 (* LBRACKET *);
  289 (* RBRACKET *);
  290 (* PIPE *);
  291 (* ARROW *);
  292 (* FUN *);
  293 (* COMMA *);
  294 (* EQUAL *);
  295 (* STAR *);
  296 (* LPAREN *);
  297 (* RPAREN *);
  298 (* COLON *);
  299 (* SEMICOLON *);
  300 (* GLOBAL *);
  301 (* TOP *);
  302 (* FIRST *);
  303 (* LAST *);
  304 (* BEFORE *);
  305 (* AFTER *);
  306 (* LEVEL *);
  307 (* LEFTA *);
  308 (* RIGHTA *);
  309 (* NONA *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  257 (* CODE *);
  258 (* COMMENT *);
  259 (* IDENT *);
  260 (* QUALID *);
  261 (* STRING *);
  262 (* INT *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\002\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\004\000\004\000\005\000\008\000\008\000\
\014\000\014\000\018\000\018\000\019\000\019\000\021\000\021\000\
\015\000\015\000\016\000\016\000\017\000\017\000\013\000\013\000\
\022\000\022\000\022\000\006\000\023\000\023\000\024\000\024\000\
\024\000\025\000\025\000\026\000\026\000\027\000\029\000\029\000\
\028\000\028\000\034\000\034\000\034\000\035\000\035\000\031\000\
\031\000\032\000\032\000\033\000\033\000\007\000\036\000\036\000\
\037\000\037\000\020\000\020\000\038\000\030\000\030\000\039\000\
\039\000\039\000\039\000\010\000\010\000\011\000\011\000\040\000\
\040\000\012\000\012\000\041\000\041\000\042\000\042\000\044\000\
\044\000\046\000\046\000\046\000\046\000\047\000\047\000\048\000\
\048\000\049\000\049\000\049\000\045\000\045\000\050\000\043\000\
\043\000\051\000\051\000\052\000\053\000\053\000\054\000\054\000\
\055\000\055\000\057\000\057\000\057\000\057\000\057\000\056\000\
\056\000\009\000\058\000\058\000\059\000\059\000\060\000\060\000\
\061\000\062\000\062\000\062\000\063\000\063\000\064\000\064\000\
\065\000\065\000\066\000\066\000\066\000\066\000\000\000"

let yylen = "\002\000\
\002\000\000\000\002\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\003\000\003\000\006\000\012\000\007\000\
\000\000\003\000\000\000\003\000\000\000\003\000\000\000\003\000\
\000\000\004\000\000\000\003\000\000\000\003\000\000\000\003\000\
\001\000\002\000\005\000\008\000\001\000\001\000\000\000\003\000\
\003\000\000\000\002\000\001\000\002\000\011\000\000\000\003\000\
\000\000\003\000\001\000\002\000\003\000\003\000\001\000\000\000\
\001\000\000\000\002\000\000\000\004\000\007\000\000\000\002\000\
\000\000\002\000\000\000\002\000\006\000\000\000\002\000\001\000\
\001\000\004\000\006\000\001\000\001\000\000\000\004\000\000\000\
\002\000\000\000\002\000\009\000\007\000\001\000\002\000\000\000\
\001\000\001\000\001\000\002\000\002\000\000\000\001\000\000\000\
\001\000\001\000\001\000\001\000\001\000\003\000\005\000\000\000\
\001\000\001\000\003\000\003\000\000\000\001\000\001\000\003\000\
\003\000\001\000\001\000\003\000\003\000\003\000\001\000\001\000\
\002\000\002\000\000\000\002\000\006\000\004\000\001\000\003\000\
\001\000\000\000\001\000\002\000\001\000\003\000\003\000\001\000\
\001\000\002\000\001\000\003\000\003\000\001\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\004\000\005\000\000\000\000\000\000\000\000\000\
\000\000\000\000\143\000\000\000\000\000\006\000\007\000\008\000\
\009\000\010\000\011\000\038\000\000\000\037\000\000\000\000\000\
\000\000\077\000\076\000\000\000\122\000\000\000\000\000\000\000\
\000\000\001\000\003\000\000\000\000\000\000\000\000\000\000\000\
\124\000\012\000\013\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\064\000\000\000\000\000\000\000\000\000\000\000\000\000\
\126\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\066\000\000\000\000\000\000\000\
\000\000\014\000\083\000\000\000\142\000\000\000\000\000\139\000\
\000\000\000\000\129\000\000\000\133\000\136\000\000\000\033\000\
\000\000\000\000\000\000\000\000\018\000\000\000\016\000\068\000\
\040\000\041\000\043\000\000\000\000\000\000\000\062\000\081\000\
\079\000\086\000\090\000\091\000\000\000\000\000\000\000\000\000\
\000\000\089\000\000\000\000\000\000\000\125\000\000\000\000\000\
\138\000\000\000\034\000\000\000\000\000\000\000\000\000\000\000\
\072\000\000\000\000\000\000\000\000\000\036\000\045\000\092\000\
\093\000\087\000\000\000\000\000\135\000\141\000\140\000\128\000\
\134\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\071\000\000\000\000\000\000\000\000\000\000\000\000\000\
\095\000\000\000\000\000\000\000\000\000\024\000\026\000\028\000\
\000\000\000\000\000\000\000\000\000\000\000\000\050\000\000\000\
\000\000\000\000\000\000\119\000\000\000\000\000\000\000\000\000\
\105\000\000\000\000\000\110\000\000\000\114\000\000\000\000\000\
\098\000\099\000\100\000\000\000\097\000\000\000\035\000\030\000\
\000\000\000\000\000\000\000\000\074\000\069\000\054\000\053\000\
\048\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\121\000\085\000\000\000\102\000\020\000\000\000\
\000\000\000\000\000\000\113\000\118\000\117\000\116\000\000\000\
\107\000\108\000\112\000\000\000\022\000\015\000\075\000\057\000\
\000\000\084\000\103\000\000\000\000\000\059\000\000\000\000\000\
\000\000\000\000\000\000\046\000\061\000"

let yydgoto = "\002\000\
\011\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\191\000\050\000\063\000\053\000\055\000\100\000\135\000\
\159\000\179\000\211\000\071\000\133\000\098\000\023\000\057\000\
\076\000\109\000\110\000\141\000\167\000\138\000\249\000\253\000\
\000\001\164\000\165\000\048\000\060\000\072\000\139\000\080\000\
\064\000\120\000\192\000\121\000\170\000\122\000\171\000\204\000\
\205\000\172\000\193\000\194\000\195\000\196\000\197\000\198\000\
\199\000\029\000\030\000\089\000\090\000\091\000\092\000\093\000\
\094\000\095\000"

let yysindex = "\011\000\
\186\255\000\000\000\000\000\000\153\255\009\255\015\255\174\255\
\020\255\021\255\000\000\059\000\186\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\059\255\000\000\089\255\094\255\
\174\255\000\000\000\000\061\255\000\000\174\255\106\255\111\255\
\126\255\000\000\000\000\135\255\140\255\143\255\142\255\123\255\
\000\000\000\000\000\000\146\255\159\255\177\255\191\255\175\255\
\182\255\174\255\171\255\197\255\159\255\199\255\194\255\184\255\
\207\255\000\000\224\255\194\255\174\255\190\255\219\255\174\255\
\000\000\025\255\010\255\208\255\233\255\203\255\225\255\194\255\
\235\255\236\255\237\255\204\255\000\000\229\255\174\255\200\255\
\169\255\000\000\000\000\206\255\000\000\025\255\077\255\000\000\
\209\255\211\255\000\000\205\255\000\000\000\000\077\255\000\000\
\010\255\243\255\215\255\223\255\000\000\018\255\000\000\000\000\
\000\000\000\000\000\000\220\255\238\255\204\255\000\000\000\000\
\000\000\000\000\000\000\000\000\247\255\249\255\250\255\221\255\
\228\255\000\000\077\255\230\255\216\255\000\000\025\255\025\255\
\000\000\016\255\000\000\253\255\234\255\240\255\242\255\231\255\
\000\000\239\255\018\255\174\255\244\255\000\000\000\000\000\000\
\000\000\000\000\245\255\014\000\000\000\000\000\000\000\000\000\
\000\000\010\255\246\255\004\000\019\000\252\255\005\000\022\000\
\251\255\000\000\254\255\255\255\241\255\023\000\002\000\081\255\
\000\000\006\000\114\255\003\000\007\255\000\000\000\000\000\000\
\026\000\007\000\013\000\035\255\028\000\174\255\000\000\174\255\
\008\000\018\255\009\000\000\000\081\255\091\255\010\000\012\000\
\000\000\015\000\016\000\000\000\018\000\000\000\091\255\020\000\
\000\000\000\000\000\000\021\000\000\000\014\000\000\000\000\000\
\032\000\024\000\194\255\033\000\000\000\000\000\000\000\000\000\
\000\000\017\000\091\255\025\000\027\000\035\000\029\000\081\255\
\041\000\081\255\000\000\000\000\081\255\000\000\000\000\042\000\
\034\000\030\000\039\000\000\000\000\000\000\000\000\000\031\000\
\000\000\000\000\000\000\036\000\000\000\000\000\000\000\000\000\
\037\000\000\000\000\000\043\000\038\000\000\000\046\000\044\000\
\045\000\054\000\055\000\000\000\000\000"

let yyrindex = "\000\000\
\059\001\000\000\000\000\000\000\000\000\000\000\000\000\001\000\
\000\000\000\000\000\000\000\000\059\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\001\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\253\254\138\255\000\000\
\000\000\000\000\000\000\110\255\006\255\249\254\000\000\076\255\
\000\000\219\255\000\000\000\000\134\255\000\000\052\000\000\000\
\047\000\000\000\000\000\052\000\040\000\000\000\000\000\219\255\
\000\000\173\255\000\000\145\255\000\000\000\000\000\000\052\000\
\000\000\000\000\000\000\000\000\000\000\000\000\040\000\000\000\
\048\000\000\000\000\000\034\255\000\000\173\255\000\000\000\000\
\000\000\049\000\000\000\187\255\000\000\000\000\167\255\000\000\
\000\000\122\255\050\000\163\255\000\000\051\000\000\000\000\000\
\000\000\000\000\000\000\086\255\000\000\053\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\173\255\189\255\
\000\000\000\000\000\000\000\000\000\000\000\000\090\255\040\255\
\000\000\000\000\051\000\000\000\056\000\000\000\000\000\000\000\
\000\000\000\000\000\000\132\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\057\255\000\000\
\000\000\000\000\248\254\000\000\057\000\000\000\000\000\156\255\
\000\000\000\000\060\000\058\000\000\000\000\000\000\000\000\000\
\000\000\000\000\092\255\000\000\000\000\000\000\000\000\061\000\
\000\000\051\000\001\255\000\000\062\000\000\000\058\255\000\000\
\000\000\063\000\000\000\000\000\064\000\000\000\168\255\000\000\
\000\000\000\000\000\000\000\000\000\000\132\255\000\000\000\000\
\000\000\000\000\052\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\062\000\
\000\000\000\000\000\000\000\000\156\255\000\000\000\000\000\000\
\000\000\000\000\070\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\095\255\000\000\000\000\000\000\065\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\053\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\248\255\000\000\003\001\000\000\017\001\000\000\000\000\
\000\000\000\000\000\000\198\255\000\000\162\255\000\000\000\000\
\000\000\218\000\000\000\000\000\000\000\124\255\000\000\000\000\
\000\000\148\000\000\000\000\000\000\000\000\000\000\000\254\000\
\000\000\000\000\112\000\000\000\136\000\000\000\000\000\000\000\
\000\000\000\000\078\255\000\000\000\000\117\000\000\000\149\255\
\000\000\063\001\000\000\178\255\000\000\000\000\000\000\217\000\
\185\255\000\000"

let yytablesize = 356
let yytable = "\028\000\
\123\000\078\000\130\000\077\000\077\000\077\000\162\000\124\000\
\063\000\131\000\220\000\001\000\096\000\104\000\039\000\125\000\
\039\000\017\000\131\000\024\000\136\000\028\000\137\000\129\000\
\055\000\025\000\039\000\084\000\027\000\085\000\063\000\033\000\
\077\000\031\000\055\000\077\000\077\000\077\000\077\000\017\000\
\077\000\062\000\073\000\077\000\073\000\241\000\063\000\207\000\
\152\000\097\000\077\000\149\000\079\000\218\000\154\000\062\000\
\086\000\088\000\034\000\173\000\115\000\115\000\115\000\032\000\
\087\000\077\000\077\000\077\000\019\000\036\000\079\000\212\000\
\073\000\077\000\019\000\213\000\077\000\088\000\088\000\026\000\
\027\000\085\000\221\000\187\000\027\000\188\000\088\000\065\000\
\056\000\115\000\019\000\227\000\115\000\026\000\027\000\188\000\
\038\000\115\000\115\000\037\000\115\000\029\000\040\000\021\000\
\056\000\056\000\029\000\029\000\086\000\065\000\042\000\236\000\
\189\000\058\000\088\000\049\000\087\000\049\000\088\000\088\000\
\190\000\031\000\189\000\029\000\043\000\021\000\031\000\031\000\
\044\000\058\000\190\000\163\000\031\000\032\000\031\000\031\000\
\031\000\045\000\032\000\032\000\078\000\078\000\046\000\031\000\
\032\000\017\000\032\000\032\000\032\000\078\000\017\000\017\000\
\233\000\020\000\051\000\032\000\025\000\047\000\017\000\017\000\
\017\000\025\000\025\000\094\000\201\000\202\000\203\000\017\000\
\021\000\052\000\025\000\025\000\022\000\215\000\027\000\163\000\
\026\000\027\000\025\000\027\000\027\000\054\000\094\000\094\000\
\094\000\049\000\003\000\004\000\104\000\027\000\109\000\058\000\
\005\000\006\000\007\000\008\000\027\000\056\000\009\000\137\000\
\137\000\010\000\120\000\065\000\066\000\130\000\130\000\137\000\
\120\000\137\000\120\000\073\000\074\000\114\000\115\000\116\000\
\117\000\118\000\119\000\131\000\131\000\132\000\132\000\061\000\
\059\000\067\000\069\000\070\000\075\000\077\000\082\000\081\000\
\099\000\101\000\102\000\105\000\103\000\108\000\106\000\107\000\
\111\000\126\000\113\000\123\000\127\000\131\000\132\000\128\000\
\134\000\142\000\140\000\144\000\147\000\145\000\146\000\155\000\
\151\000\123\000\123\000\148\000\175\000\156\000\150\000\123\000\
\123\000\123\000\123\000\157\000\158\000\123\000\160\000\161\000\
\123\000\166\000\169\000\176\000\168\000\178\000\174\000\177\000\
\180\000\185\000\208\000\184\000\214\000\181\000\210\000\183\000\
\231\000\186\000\209\000\182\000\206\000\234\000\200\000\239\000\
\217\000\242\000\245\000\254\000\223\000\246\000\219\000\003\001\
\224\000\235\000\225\000\232\000\229\000\248\000\004\001\005\001\
\255\000\237\000\002\000\222\000\226\000\240\000\228\000\067\000\
\044\000\035\000\083\000\238\000\251\000\068\000\247\000\143\000\
\252\000\250\000\001\001\216\000\112\000\023\000\002\001\088\000\
\042\000\127\000\080\000\070\000\244\000\230\000\243\000\047\000\
\153\000\051\000\101\000\096\000\041\000\052\000\000\000\106\000\
\109\000\000\000\111\000\060\000"

let yycheck = "\008\000\
\000\000\060\000\097\000\003\001\004\001\005\001\139\000\086\000\
\012\001\003\001\189\000\001\000\003\001\072\000\022\001\087\000\
\025\000\012\001\003\001\011\001\003\001\030\000\005\001\095\000\
\033\001\011\001\034\001\003\001\004\001\005\001\034\001\011\001\
\032\001\014\001\043\001\035\001\003\001\004\001\005\001\034\001\
\040\001\050\000\003\001\043\001\005\001\224\000\050\001\041\001\
\127\000\040\001\050\001\123\000\061\000\186\000\039\001\064\000\
\032\001\066\000\000\000\154\000\003\001\004\001\005\001\044\001\
\040\001\032\001\033\001\034\001\012\001\011\001\079\000\037\001\
\033\001\040\001\018\001\041\001\043\001\086\000\087\000\003\001\
\004\001\005\001\190\000\003\001\004\001\005\001\095\000\012\001\
\019\001\032\001\034\001\199\000\035\001\003\001\004\001\005\001\
\003\001\040\001\041\001\011\001\043\001\012\001\042\001\012\001\
\035\001\036\001\017\001\018\001\032\001\034\001\005\001\219\000\
\032\001\019\001\123\000\030\001\040\001\032\001\127\000\128\000\
\040\001\012\001\032\001\034\001\014\001\034\001\017\001\018\001\
\003\001\035\001\040\001\140\000\023\001\012\001\025\001\026\001\
\027\001\003\001\017\001\018\001\003\001\004\001\003\001\034\001\
\023\001\012\001\025\001\026\001\027\001\012\001\017\001\018\001\
\211\000\001\001\032\001\034\001\012\001\015\001\025\001\026\001\
\027\001\017\001\018\001\032\001\051\001\052\001\053\001\034\001\
\016\001\024\001\026\001\027\001\020\001\182\000\012\001\184\000\
\003\001\004\001\034\001\017\001\018\001\023\001\051\001\052\001\
\053\001\044\001\001\001\002\001\033\001\027\001\035\001\001\001\
\007\001\008\001\009\001\010\001\034\001\021\001\013\001\033\001\
\034\001\016\001\035\001\033\001\034\001\033\001\034\001\041\001\
\041\001\043\001\043\001\028\001\029\001\045\001\046\001\047\001\
\048\001\049\001\050\001\033\001\034\001\033\001\034\001\042\001\
\050\001\029\001\028\001\034\001\022\001\006\001\012\001\042\001\
\025\001\001\001\032\001\001\001\012\001\034\001\003\001\003\001\
\012\001\033\001\043\001\038\001\034\001\003\001\032\001\043\001\
\026\001\012\001\031\001\005\001\032\001\005\001\005\001\003\001\
\041\001\001\001\002\001\032\001\001\001\028\001\033\001\007\001\
\008\001\009\001\010\001\028\001\027\001\013\001\040\001\033\001\
\016\001\030\001\005\001\001\001\032\001\017\001\033\001\028\001\
\003\001\003\001\001\001\043\001\001\001\035\001\018\001\033\001\
\001\001\032\001\028\001\038\001\034\001\005\001\033\001\005\001\
\033\001\001\001\001\001\001\001\033\001\012\001\038\001\003\001\
\034\001\033\001\035\001\028\001\032\001\015\001\001\001\001\001\
\019\001\033\001\000\000\050\001\043\001\033\001\043\001\012\001\
\012\001\013\000\064\000\041\001\033\001\053\000\041\001\110\000\
\036\001\043\001\029\001\184\000\079\000\028\001\035\001\032\001\
\034\001\033\001\043\001\033\001\229\000\206\000\226\000\032\001\
\128\000\033\001\033\001\032\001\030\000\033\001\255\255\033\001\
\035\001\255\255\035\001\035\001"

let yynames_const = "\
  VERNAC\000\
  TACTIC\000\
  GRAMMAR\000\
  DOC_GRAMMAR\000\
  EXTEND\000\
  END\000\
  DECLARE\000\
  PLUGIN\000\
  DEPRECATED\000\
  ARGUMENT\000\
  RAW_PRINTED\000\
  GLOB_PRINTED\000\
  SYNTERP\000\
  COMMAND\000\
  CLASSIFIED\000\
  STATE\000\
  PRINTED\000\
  TYPED\000\
  INTERPRETED\000\
  GLOBALIZED\000\
  SUBSTITUTED\000\
  BY\000\
  AS\000\
  BANGBRACKET\000\
  HASHBRACKET\000\
  LBRACKET\000\
  RBRACKET\000\
  PIPE\000\
  ARROW\000\
  FUN\000\
  COMMA\000\
  EQUAL\000\
  STAR\000\
  LPAREN\000\
  RPAREN\000\
  COLON\000\
  SEMICOLON\000\
  GLOBAL\000\
  TOP\000\
  FIRST\000\
  LAST\000\
  BEFORE\000\
  AFTER\000\
  LEVEL\000\
  LEFTA\000\
  RIGHTA\000\
  NONA\000\
  EOF\000\
  "

let yynames_block = "\
  CODE\000\
  COMMENT\000\
  IDENT\000\
  QUALID\000\
  STRING\000\
  INT\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'nodes) in
    Obj.repr(
# 84 "coqpp/coqpp_parse.mly"
  ( _1 )
# 501 "coqpp/coqpp_parse.ml"
               : Coqpp_ast.t))
; (fun __caml_parser_env ->
    Obj.repr(
# 89 "coqpp/coqpp_parse.mly"
  ( [] )
# 507 "coqpp/coqpp_parse.ml"
               : 'nodes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'node) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'nodes) in
    Obj.repr(
# 91 "coqpp/coqpp_parse.mly"
  ( _1 :: _2 )
# 515 "coqpp/coqpp_parse.ml"
               : 'nodes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 95 "coqpp/coqpp_parse.mly"
       ( Code _1 )
# 522 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 96 "coqpp/coqpp_parse.mly"
          ( Comment _1 )
# 529 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'declare_plugin) in
    Obj.repr(
# 97 "coqpp/coqpp_parse.mly"
                 ( _1 )
# 536 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'grammar_extend) in
    Obj.repr(
# 98 "coqpp/coqpp_parse.mly"
                 ( _1 )
# 543 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_extend) in
    Obj.repr(
# 99 "coqpp/coqpp_parse.mly"
                ( _1 )
# 550 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'tactic_extend) in
    Obj.repr(
# 100 "coqpp/coqpp_parse.mly"
                ( _1 )
# 557 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'argument_extend) in
    Obj.repr(
# 101 "coqpp/coqpp_parse.mly"
                  ( _1 )
# 564 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram) in
    Obj.repr(
# 102 "coqpp/coqpp_parse.mly"
           ( _1 )
# 571 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 106 "coqpp/coqpp_parse.mly"
                        ( DeclarePlugin (Some _3) )
# 578 "coqpp/coqpp_parse.ml"
               : 'declare_plugin))
; (fun __caml_parser_env ->
    Obj.repr(
# 107 "coqpp/coqpp_parse.mly"
                        ( DeclarePlugin None )
# 584 "coqpp/coqpp_parse.ml"
               : 'declare_plugin))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'qualid_or_ident) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'globals) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'gram_entries) in
    Obj.repr(
# 112 "coqpp/coqpp_parse.mly"
  ( GramExt { gramext_name = _3; gramext_globals = _4; gramext_entries = _5 } )
# 593 "coqpp/coqpp_parse.ml"
               : 'grammar_extend))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 9 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 8 : 'typed_opt) in
    let _5 = (Parsing.peek_val __caml_parser_env 7 : 'printed_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 6 : 'interpreted_opt) in
    let _7 = (Parsing.peek_val __caml_parser_env 5 : 'globalized_opt) in
    let _8 = (Parsing.peek_val __caml_parser_env 4 : 'substituted_opt) in
    let _9 = (Parsing.peek_val __caml_parser_env 3 : 'raw_printed_opt) in
    let _10 = (Parsing.peek_val __caml_parser_env 2 : 'glob_printed_opt) in
    let _11 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rules) in
    Obj.repr(
# 126 "coqpp/coqpp_parse.mly"
  ( ArgumentExt {
    argext_name = _3;
    argext_rules = _11;
    argext_rprinter = _9;
    argext_gprinter = _10;
    argext_tprinter = _5;
    argext_interp = _6;
    argext_glob = _7;
    argext_subst = _8;
    argext_type = _4;
  } )
# 618 "coqpp/coqpp_parse.ml"
               : 'argument_extend))
; (fun __caml_parser_env ->
    let _4 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'printed_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rules) in
    Obj.repr(
# 138 "coqpp/coqpp_parse.mly"
  ( VernacArgumentExt {
    vernacargext_name = _4;
    vernacargext_printer = _5;
    vernacargext_rules = _6;
  } )
# 631 "coqpp/coqpp_parse.ml"
               : 'argument_extend))
; (fun __caml_parser_env ->
    Obj.repr(
# 146 "coqpp/coqpp_parse.mly"
  ( None )
# 637 "coqpp/coqpp_parse.ml"
               : 'printed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 147 "coqpp/coqpp_parse.mly"
                  ( Some _3 )
# 644 "coqpp/coqpp_parse.ml"
               : 'printed_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 151 "coqpp/coqpp_parse.mly"
  ( None )
# 650 "coqpp/coqpp_parse.ml"
               : 'raw_printed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 152 "coqpp/coqpp_parse.mly"
                      ( Some _3 )
# 657 "coqpp/coqpp_parse.ml"
               : 'raw_printed_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 156 "coqpp/coqpp_parse.mly"
  ( None )
# 663 "coqpp/coqpp_parse.ml"
               : 'glob_printed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 157 "coqpp/coqpp_parse.mly"
                       ( Some _3 )
# 670 "coqpp/coqpp_parse.ml"
               : 'glob_printed_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 161 "coqpp/coqpp_parse.mly"
  ( None )
# 676 "coqpp/coqpp_parse.ml"
               : 'interpreted_modifier_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 162 "coqpp/coqpp_parse.mly"
                          ( Some _2 )
# 683 "coqpp/coqpp_parse.ml"
               : 'interpreted_modifier_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 166 "coqpp/coqpp_parse.mly"
  ( None )
# 689 "coqpp/coqpp_parse.ml"
               : 'interpreted_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'interpreted_modifier_opt) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 167 "coqpp/coqpp_parse.mly"
                                               ( Some (_2,_4) )
# 697 "coqpp/coqpp_parse.ml"
               : 'interpreted_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 171 "coqpp/coqpp_parse.mly"
  ( None )
# 703 "coqpp/coqpp_parse.ml"
               : 'globalized_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 172 "coqpp/coqpp_parse.mly"
                     ( Some _3 )
# 710 "coqpp/coqpp_parse.ml"
               : 'globalized_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 176 "coqpp/coqpp_parse.mly"
  ( None )
# 716 "coqpp/coqpp_parse.ml"
               : 'substituted_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 177 "coqpp/coqpp_parse.mly"
                      ( Some _3 )
# 723 "coqpp/coqpp_parse.ml"
               : 'substituted_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 181 "coqpp/coqpp_parse.mly"
  ( None )
# 729 "coqpp/coqpp_parse.ml"
               : 'typed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'argtype) in
    Obj.repr(
# 182 "coqpp/coqpp_parse.mly"
                   ( Some _3 )
# 736 "coqpp/coqpp_parse.ml"
               : 'typed_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 186 "coqpp/coqpp_parse.mly"
        ( ExtraArgType _1 )
# 743 "coqpp/coqpp_parse.ml"
               : 'argtype))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'argtype) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 187 "coqpp/coqpp_parse.mly"
                (
    match _2 with
    | "list" -> ListArgType _1
    | "option" ->  OptArgType _1
    | _ -> raise Parsing.Parse_error
  )
# 756 "coqpp/coqpp_parse.ml"
               : 'argtype))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'argtype) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'argtype) in
    Obj.repr(
# 193 "coqpp/coqpp_parse.mly"
                                     ( PairArgType (_2, _4) )
# 764 "coqpp/coqpp_parse.ml"
               : 'argtype))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : 'vernac_entry) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'vernac_classifier) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : 'vernac_state) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_rules) in
    Obj.repr(
# 198 "coqpp/coqpp_parse.mly"
  ( VernacExt {
    vernacext_name = _4;
    vernacext_entry = _2;
    vernacext_class = _5;
    vernacext_state = _6;
    vernacext_rules = _7;
  } )
# 781 "coqpp/coqpp_parse.ml"
               : 'vernac_extend))
; (fun __caml_parser_env ->
    Obj.repr(
# 208 "coqpp/coqpp_parse.mly"
          ( None )
# 787 "coqpp/coqpp_parse.ml"
               : 'vernac_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 209 "coqpp/coqpp_parse.mly"
       ( Some _1 )
# 794 "coqpp/coqpp_parse.ml"
               : 'vernac_entry))
; (fun __caml_parser_env ->
    Obj.repr(
# 213 "coqpp/coqpp_parse.mly"
  ( ClassifDefault )
# 800 "coqpp/coqpp_parse.ml"
               : 'vernac_classifier))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 214 "coqpp/coqpp_parse.mly"
                     ( ClassifCode _3 )
# 807 "coqpp/coqpp_parse.ml"
               : 'vernac_classifier))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 215 "coqpp/coqpp_parse.mly"
                      ( ClassifName _3 )
# 814 "coqpp/coqpp_parse.ml"
               : 'vernac_classifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 219 "coqpp/coqpp_parse.mly"
  ( None )
# 820 "coqpp/coqpp_parse.ml"
               : 'vernac_state))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 220 "coqpp/coqpp_parse.mly"
              ( Some _2 )
# 827 "coqpp/coqpp_parse.ml"
               : 'vernac_state))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_rule) in
    Obj.repr(
# 224 "coqpp/coqpp_parse.mly"
              ( [_1] )
# 834 "coqpp/coqpp_parse.ml"
               : 'vernac_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_rule) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_rules) in
    Obj.repr(
# 225 "coqpp/coqpp_parse.mly"
                           ( _1 :: _2 )
# 842 "coqpp/coqpp_parse.ml"
               : 'vernac_rules))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 9 : 'vernac_attributes_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 8 : 'rule_state) in
    let _5 = (Parsing.peek_val __caml_parser_env 6 : 'ext_tokens) in
    let _7 = (Parsing.peek_val __caml_parser_env 4 : 'rule_deprecation) in
    let _8 = (Parsing.peek_val __caml_parser_env 3 : 'rule_classifier) in
    let _9 = (Parsing.peek_val __caml_parser_env 2 : 'synterp_fun) in
    let _11 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 230 "coqpp/coqpp_parse.mly"
  ( {
      vernac_atts = _2;
      vernac_state = _3;
      vernac_toks = _5;
      vernac_depr = _7;
      vernac_class= _8;
      vernac_synterp = _9;
      vernac_body = _11;
  } )
# 863 "coqpp/coqpp_parse.ml"
               : 'vernac_rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 242 "coqpp/coqpp_parse.mly"
  ( None )
# 869 "coqpp/coqpp_parse.ml"
               : 'rule_state))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 243 "coqpp/coqpp_parse.mly"
                             ( Some _2 )
# 876 "coqpp/coqpp_parse.ml"
               : 'rule_state))
; (fun __caml_parser_env ->
    Obj.repr(
# 247 "coqpp/coqpp_parse.mly"
  ( None )
# 882 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_attributes) in
    Obj.repr(
# 248 "coqpp/coqpp_parse.mly"
                                         ( Some _2 )
# 889 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_attribute) in
    Obj.repr(
# 252 "coqpp/coqpp_parse.mly"
                   ( [_1] )
# 896 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_attribute) in
    Obj.repr(
# 253 "coqpp/coqpp_parse.mly"
                             ( [_1] )
# 903 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'vernac_attribute) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_attributes) in
    Obj.repr(
# 254 "coqpp/coqpp_parse.mly"
                                               ( _1 :: _3 )
# 911 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 258 "coqpp/coqpp_parse.mly"
                                        ( (_1, _3) )
# 919 "coqpp/coqpp_parse.ml"
               : 'vernac_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 259 "coqpp/coqpp_parse.mly"
                  ( (_1, _1) )
# 926 "coqpp/coqpp_parse.ml"
               : 'vernac_attribute))
; (fun __caml_parser_env ->
    Obj.repr(
# 263 "coqpp/coqpp_parse.mly"
  ( false )
# 932 "coqpp/coqpp_parse.ml"
               : 'rule_deprecation))
; (fun __caml_parser_env ->
    Obj.repr(
# 264 "coqpp/coqpp_parse.mly"
             ( true )
# 938 "coqpp/coqpp_parse.ml"
               : 'rule_deprecation))
; (fun __caml_parser_env ->
    Obj.repr(
# 268 "coqpp/coqpp_parse.mly"
  ( None )
# 944 "coqpp/coqpp_parse.ml"
               : 'rule_classifier))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 269 "coqpp/coqpp_parse.mly"
           ( Some _2 )
# 951 "coqpp/coqpp_parse.ml"
               : 'rule_classifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 273 "coqpp/coqpp_parse.mly"
  ( None )
# 957 "coqpp/coqpp_parse.ml"
               : 'synterp_fun))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 274 "coqpp/coqpp_parse.mly"
                        ( Some (_3,_4) )
# 965 "coqpp/coqpp_parse.ml"
               : 'synterp_fun))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'tactic_deprecated) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'tactic_level) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rules) in
    Obj.repr(
# 278 "coqpp/coqpp_parse.mly"
  ( TacticExt { tacext_name = _3; tacext_deprecated = _4; tacext_level = _5; tacext_rules = _6 } )
# 975 "coqpp/coqpp_parse.ml"
               : 'tactic_extend))
; (fun __caml_parser_env ->
    Obj.repr(
# 282 "coqpp/coqpp_parse.mly"
  ( None )
# 981 "coqpp/coqpp_parse.ml"
               : 'tactic_deprecated))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 283 "coqpp/coqpp_parse.mly"
                  ( Some _2 )
# 988 "coqpp/coqpp_parse.ml"
               : 'tactic_deprecated))
; (fun __caml_parser_env ->
    Obj.repr(
# 287 "coqpp/coqpp_parse.mly"
  ( None )
# 994 "coqpp/coqpp_parse.ml"
               : 'tactic_level))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : int) in
    Obj.repr(
# 288 "coqpp/coqpp_parse.mly"
            ( Some _2 )
# 1001 "coqpp/coqpp_parse.ml"
               : 'tactic_level))
; (fun __caml_parser_env ->
    Obj.repr(
# 292 "coqpp/coqpp_parse.mly"
  ( [] )
# 1007 "coqpp/coqpp_parse.ml"
               : 'tactic_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rule) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'tactic_rules) in
    Obj.repr(
# 293 "coqpp/coqpp_parse.mly"
                           ( _1 :: _2 )
# 1015 "coqpp/coqpp_parse.ml"
               : 'tactic_rules))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'ext_tokens) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 298 "coqpp/coqpp_parse.mly"
  ( { tac_toks = _3; tac_body = _6 } )
# 1023 "coqpp/coqpp_parse.ml"
               : 'tactic_rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 302 "coqpp/coqpp_parse.mly"
  ( [] )
# 1029 "coqpp/coqpp_parse.ml"
               : 'ext_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'ext_token) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ext_tokens) in
    Obj.repr(
# 303 "coqpp/coqpp_parse.mly"
                       ( _1 :: _2 )
# 1037 "coqpp/coqpp_parse.ml"
               : 'ext_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 307 "coqpp/coqpp_parse.mly"
         ( ExtTerminal _1 )
# 1044 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 308 "coqpp/coqpp_parse.mly"
        (
  let e = parse_user_entry _1 "" in
  ExtNonTerminal (e, TokNone) 
  )
# 1054 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 312 "coqpp/coqpp_parse.mly"
                            (
  let e = parse_user_entry _1 "" in
  ExtNonTerminal (e, TokName _3)
  )
# 1065 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 316 "coqpp/coqpp_parse.mly"
                                         (
  let e = parse_user_entry _1 _5 in
  ExtNonTerminal (e, TokName _3)
)
# 1077 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 323 "coqpp/coqpp_parse.mly"
         ( _1 )
# 1084 "coqpp/coqpp_parse.ml"
               : 'qualid_or_ident))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 324 "coqpp/coqpp_parse.mly"
        ( _1 )
# 1091 "coqpp/coqpp_parse.ml"
               : 'qualid_or_ident))
; (fun __caml_parser_env ->
    Obj.repr(
# 328 "coqpp/coqpp_parse.mly"
  ( [] )
# 1097 "coqpp/coqpp_parse.ml"
               : 'globals))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'idents) in
    Obj.repr(
# 329 "coqpp/coqpp_parse.mly"
                                ( _3 )
# 1104 "coqpp/coqpp_parse.ml"
               : 'globals))
; (fun __caml_parser_env ->
    Obj.repr(
# 333 "coqpp/coqpp_parse.mly"
  ( [] )
# 1110 "coqpp/coqpp_parse.ml"
               : 'idents))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'qualid_or_ident) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'idents) in
    Obj.repr(
# 334 "coqpp/coqpp_parse.mly"
                         ( _1 :: _2 )
# 1118 "coqpp/coqpp_parse.ml"
               : 'idents))
; (fun __caml_parser_env ->
    Obj.repr(
# 338 "coqpp/coqpp_parse.mly"
  ( [] )
# 1124 "coqpp/coqpp_parse.ml"
               : 'gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gram_entry) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'gram_entries) in
    Obj.repr(
# 339 "coqpp/coqpp_parse.mly"
                          ( _1 :: _2 )
# 1132 "coqpp/coqpp_parse.ml"
               : 'gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : 'reuse) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'rules_opt) in
    Obj.repr(
# 344 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1; gentry_rules = GDataReuse (_3, _6); } )
# 1141 "coqpp/coqpp_parse.ml"
               : 'gram_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'position_opt) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'levels) in
    Obj.repr(
# 346 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1; gentry_rules = GDataFresh (_3, _5); } )
# 1150 "coqpp/coqpp_parse.ml"
               : 'gram_entry))
; (fun __caml_parser_env ->
    Obj.repr(
# 350 "coqpp/coqpp_parse.mly"
      ( None )
# 1156 "coqpp/coqpp_parse.ml"
               : 'reuse))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 351 "coqpp/coqpp_parse.mly"
               ( Some _2 )
# 1163 "coqpp/coqpp_parse.ml"
               : 'reuse))
; (fun __caml_parser_env ->
    Obj.repr(
# 355 "coqpp/coqpp_parse.mly"
  ( None )
# 1169 "coqpp/coqpp_parse.ml"
               : 'position_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'position) in
    Obj.repr(
# 356 "coqpp/coqpp_parse.mly"
           ( Some _1 )
# 1176 "coqpp/coqpp_parse.ml"
               : 'position_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 360 "coqpp/coqpp_parse.mly"
        ( First )
# 1182 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    Obj.repr(
# 361 "coqpp/coqpp_parse.mly"
       ( Last )
# 1188 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 362 "coqpp/coqpp_parse.mly"
                ( Before _2 )
# 1195 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 363 "coqpp/coqpp_parse.mly"
               ( After _2 )
# 1202 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    Obj.repr(
# 367 "coqpp/coqpp_parse.mly"
  ( None )
# 1208 "coqpp/coqpp_parse.ml"
               : 'string_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 368 "coqpp/coqpp_parse.mly"
         ( Some _1 )
# 1215 "coqpp/coqpp_parse.ml"
               : 'string_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 372 "coqpp/coqpp_parse.mly"
  ( None )
# 1221 "coqpp/coqpp_parse.ml"
               : 'assoc_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assoc) in
    Obj.repr(
# 373 "coqpp/coqpp_parse.mly"
        ( Some _1 )
# 1228 "coqpp/coqpp_parse.ml"
               : 'assoc_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 377 "coqpp/coqpp_parse.mly"
        ( LeftA )
# 1234 "coqpp/coqpp_parse.ml"
               : 'assoc))
; (fun __caml_parser_env ->
    Obj.repr(
# 378 "coqpp/coqpp_parse.mly"
         ( RightA )
# 1240 "coqpp/coqpp_parse.ml"
               : 'assoc))
; (fun __caml_parser_env ->
    Obj.repr(
# 379 "coqpp/coqpp_parse.mly"
       ( NonA )
# 1246 "coqpp/coqpp_parse.ml"
               : 'assoc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'level) in
    Obj.repr(
# 383 "coqpp/coqpp_parse.mly"
        ( [_1] )
# 1253 "coqpp/coqpp_parse.ml"
               : 'levels))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'level) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'levels) in
    Obj.repr(
# 384 "coqpp/coqpp_parse.mly"
                    ( _1 :: _3 )
# 1261 "coqpp/coqpp_parse.ml"
               : 'levels))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'string_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'assoc_opt) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'rules_opt) in
    Obj.repr(
# 389 "coqpp/coqpp_parse.mly"
  ( { grule_label = _1; grule_assoc = _2; grule_prods = _4; } )
# 1270 "coqpp/coqpp_parse.ml"
               : 'level))
; (fun __caml_parser_env ->
    Obj.repr(
# 393 "coqpp/coqpp_parse.mly"
  ( [] )
# 1276 "coqpp/coqpp_parse.ml"
               : 'rules_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'rules) in
    Obj.repr(
# 394 "coqpp/coqpp_parse.mly"
        ( _1 )
# 1283 "coqpp/coqpp_parse.ml"
               : 'rules_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'rule) in
    Obj.repr(
# 398 "coqpp/coqpp_parse.mly"
       ( [_1] )
# 1290 "coqpp/coqpp_parse.ml"
               : 'rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'rule) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'rules) in
    Obj.repr(
# 399 "coqpp/coqpp_parse.mly"
                  ( _1 :: _3 )
# 1298 "coqpp/coqpp_parse.ml"
               : 'rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'symbols_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 404 "coqpp/coqpp_parse.mly"
  ( { gprod_symbs = _1; gprod_body = _3; } )
# 1306 "coqpp/coqpp_parse.ml"
               : 'rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 408 "coqpp/coqpp_parse.mly"
  ( [] )
# 1312 "coqpp/coqpp_parse.ml"
               : 'symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'symbols) in
    Obj.repr(
# 409 "coqpp/coqpp_parse.mly"
          ( _1 )
# 1319 "coqpp/coqpp_parse.ml"
               : 'symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'symbol) in
    Obj.repr(
# 413 "coqpp/coqpp_parse.mly"
         ( [_1] )
# 1326 "coqpp/coqpp_parse.ml"
               : 'symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'symbol) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'symbols) in
    Obj.repr(
# 414 "coqpp/coqpp_parse.mly"
                           ( _1 :: _3 )
# 1334 "coqpp/coqpp_parse.ml"
               : 'symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'gram_tokens) in
    Obj.repr(
# 418 "coqpp/coqpp_parse.mly"
                          ( (Some _1, _3) )
# 1342 "coqpp/coqpp_parse.ml"
               : 'symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'gram_tokens) in
    Obj.repr(
# 419 "coqpp/coqpp_parse.mly"
              ( (None, _1) )
# 1349 "coqpp/coqpp_parse.ml"
               : 'symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 423 "coqpp/coqpp_parse.mly"
                  ( GSymbQualid (_1, None) )
# 1356 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 424 "coqpp/coqpp_parse.mly"
                               ( GSymbQualid (_1, Some _3) )
# 1364 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'gram_tokens) in
    Obj.repr(
# 425 "coqpp/coqpp_parse.mly"
                            ( GSymbParen _2 )
# 1371 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'rules) in
    Obj.repr(
# 426 "coqpp/coqpp_parse.mly"
                          ( GSymbProd _2 )
# 1378 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 427 "coqpp/coqpp_parse.mly"
         ( GSymbString _1 )
# 1385 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'gram_token) in
    Obj.repr(
# 431 "coqpp/coqpp_parse.mly"
             ( [_1] )
# 1392 "coqpp/coqpp_parse.ml"
               : 'gram_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gram_token) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'gram_tokens) in
    Obj.repr(
# 432 "coqpp/coqpp_parse.mly"
                         ( _1 :: _2 )
# 1400 "coqpp/coqpp_parse.ml"
               : 'gram_tokens))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_entries) in
    Obj.repr(
# 437 "coqpp/coqpp_parse.mly"
  ( GramExt { gramext_name = ""; gramext_globals=[]; gramext_entries = _2 } )
# 1407 "coqpp/coqpp_parse.ml"
               : 'doc_gram))
; (fun __caml_parser_env ->
    Obj.repr(
# 440 "coqpp/coqpp_parse.mly"
  ( [] )
# 1413 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_entry) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_entries) in
    Obj.repr(
# 441 "coqpp/coqpp_parse.mly"
                                   ( _1 :: _2 )
# 1421 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'qualid_or_ident) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_rules) in
    Obj.repr(
# 446 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1;
      gentry_rules = GDataFresh (None, [{ grule_label = None; grule_assoc = None; grule_prods = _5; }]) } )
# 1430 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'qualid_or_ident) in
    Obj.repr(
# 449 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1;
      gentry_rules = GDataFresh (None, [{ grule_label = None; grule_assoc = None; grule_prods = []; }]) } )
# 1438 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_rule) in
    Obj.repr(
# 454 "coqpp/coqpp_parse.mly"
                ( [_1] )
# 1445 "coqpp/coqpp_parse.ml"
               : 'doc_gram_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'doc_gram_rule) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_rules) in
    Obj.repr(
# 455 "coqpp/coqpp_parse.mly"
                                    ( _1 :: _3 )
# 1453 "coqpp/coqpp_parse.ml"
               : 'doc_gram_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbols_opt) in
    Obj.repr(
# 459 "coqpp/coqpp_parse.mly"
                       ( { gprod_symbs = _1; gprod_body = no_code; } )
# 1460 "coqpp/coqpp_parse.ml"
               : 'doc_gram_rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 463 "coqpp/coqpp_parse.mly"
  ( [] )
# 1466 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbols) in
    Obj.repr(
# 464 "coqpp/coqpp_parse.mly"
                   ( _1 )
# 1473 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_symbols) in
    Obj.repr(
# 465 "coqpp/coqpp_parse.mly"
                             ( _1 )
# 1480 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbol) in
    Obj.repr(
# 469 "coqpp/coqpp_parse.mly"
                  ( [_1] )
# 1487 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'doc_gram_symbols) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbol) in
    Obj.repr(
# 470 "coqpp/coqpp_parse.mly"
                                             ( _1 @ [_3] )
# 1495 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 474 "coqpp/coqpp_parse.mly"
                                   ( (Some _1, _3) )
# 1503 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 475 "coqpp/coqpp_parse.mly"
                       ( (None, _1) )
# 1510 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_token) in
    Obj.repr(
# 479 "coqpp/coqpp_parse.mly"
                      ( [_1] )
# 1517 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_gram_token) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 480 "coqpp/coqpp_parse.mly"
                                           ( _1 :: _2 )
# 1525 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 484 "coqpp/coqpp_parse.mly"
                  ( GSymbQualid (_1, None) )
# 1532 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 485 "coqpp/coqpp_parse.mly"
                                     ( GSymbParen _2 )
# 1539 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_rules) in
    Obj.repr(
# 486 "coqpp/coqpp_parse.mly"
                                   ( GSymbProd _2 )
# 1546 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 487 "coqpp/coqpp_parse.mly"
         ( GSymbString _1 )
# 1553 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Coqpp_ast.t)
